==> jsf-impl-1.2_15-06-sources.jar: com/sun/faces/el/ELConstants.java <==
/*
 * $Id: ELConstants.java,v 1.7 2007/07/17 23:14:01 rlubke Exp $
 */

/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 * 
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 * 
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 * 
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 * 
 * Contributor(s):
 * 
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package com.sun.faces.el;

/**
 * @author jhook
 */
public interface ELConstants {
    public static final int APPLICATION = 0;

    public static final int APPLICATION_SCOPE = 1;

    public static final int COOKIE = 2;

    public static final int FACES_CONTEXT = 3;

    public static final int HEADER = 4;

    public static final int HEADER_VALUES = 5;

    public static final int INIT_PARAM = 6;

    public static final int PARAM = 7;

    public static final int PARAM_VALUES = 8;

    public static final int REQUEST = 9;

    public static final int REQUEST_SCOPE = 10;

    public static final int SESSION = 11;

    public static final int SESSION_SCOPE = 12;

    public static final int VIEW = 13;
    
}

==> jsf-impl-2.0.0-b13-sources.jar: com/sun/faces/el/ELConstants.java <==
/*
 * $Id: ELConstants.java,v 1.8.8.1 2008/03/14 02:41:02 edburns Exp $
 */

/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 * 
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 * 
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 * 
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 * 
 * Contributor(s):
 * 
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package com.sun.faces.el;

/**
 * @author jhook
 */
public interface ELConstants {
    public static final int APPLICATION = 0;

    public static final int APPLICATION_SCOPE = 1;

    public static final int COMPOSITE_COMPONENT = 2;

    public static final int COMPONENT = 3;

    public static final int COOKIE = 4;

    public static final int FACES_CONTEXT = 5;

    public static final int HEADER = 6;

    public static final int HEADER_VALUES = 7;

    public static final int INIT_PARAM = 8;

    public static final int PARAM = 9;

    public static final int PARAM_VALUES = 10;

    public static final int REQUEST = 11;

    public static final int REQUEST_SCOPE = 12;

    public static final int RESOURCE = 13;

    public static final int SESSION = 14;

    public static final int SESSION_SCOPE = 15;

    public static final int VIEW = 16;

    public static final int VIEW_SCOPE = 17;
    
}
